@@ -44,31 +44,31 @@ class EncoderOpus : public QObject, public AudioCDEncoder {
     Q_OBJECT
 
 public:
-    explicit EncoderOpus(KIO::SlaveBase *slave);
-    ~EncoderOpus();
+    explicit EncoderOpus(KIO::WorkerBase *worker);
+    ~EncoderOpus() override;
 
-    virtual QString type() const override
+    QString type() const override
     {
         return QStringLiteral("Opus");
     }
-    virtual bool init() override;
-    virtual void loadSettings() override;
-    virtual unsigned long size(long time_secs) const override;
-    virtual const char *fileType() const override
+    bool init() override;
+    void loadSettings() override;
+    unsigned long size(long time_secs) const override;
+    const char *fileType() const override
     {
         return "opus";
     }
-    virtual const char *mimeType() const override
+    const char *mimeType() const override
     {
         return "audio/x-opus+ogg";
     }
-    virtual void fillSongInfo(KCDDB::CDInfo info, int track, const QString &comment) override;
-    virtual long readInit(long size) override;
-    virtual long read(qint16 *buf, int frames) override;
-    virtual long readCleanup() override;
-    virtual QString lastErrorMessage() const override;
+    void fillSongInfo(KCDDB::CDInfo info, int track, const QString &comment) override;
+    long readInit(long size) override;
+    long read(qint16 *buf, int frames) override;
+    long readCleanup() override;
+    QString lastErrorMessage() const override;
 
-    virtual QWidget *getConfigureWidget(KConfigSkeleton **manager) const override;
+    QWidget *getConfigureWidget(KConfigSkeleton **manager) const override;
 
 protected Q_SLOTS:
     void receivedStdout();
